#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the nuImages dataset."""

from tensorbay.opendataset.nuImages.loader import nuImages

__all__ = ["nuImages"]
